@@ -1,5 +1,5 @@
 def isMath(formula):
-    caracteristicSymbols = ['\\', '/', '*', '-', '(', ')', '_', '^', '+', '[', ']', '{', '}', '=']
+    caracteristicSymbols = ['\\', '/', '*', '-', '(', ')', '_', '^', '+', '[', ']', '{', '}', '=', 'sqrt', '0', '1', '2', '3','4', '5','6', '7','8', '9']
     for e in caracteristicSymbols:
         if e in formula:
             return True
